/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-20 17:18:52
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-09-09 10:58:26
 * @FilePath: \Game-Backstage-Management-System\src\utils\axios\axiosInstance.ts
 * @Description:
 *
 */
// 引入axios
import axios from 'axios'
import router from '@/router'
import { ElMessage } from 'element-plus'
import { useRequest } from '@/hooks/useRequest'
import { MessageType } from '@/types/res'

const { AllApi } = useRequest()
// 创建axios实例
const axiosInstance = axios.create()
// 请求拦截器
axiosInstance.interceptors.request.use(
  function (config) {
    // console.log(config);
    if (config.url === AllApi.gerRefreshToken) {
      let refreshToken = localStorage.getItem('refreshToken')
      if (refreshToken) {
        config.headers.Authorization = refreshToken
      }
      console.log(config.headers.Authorization)
    } else if (config.url !== AllApi.userLogin) {
      let token = localStorage.getItem('token')

      if (token) {
        config.headers.Authorization = token
      }
    }

    // 在发送请求之前做些什么
    return config
  },
  function (error) {
    // 对请求错误做些什么
    return Promise.reject(error)
  }
)
// 添加响应拦截器
axiosInstance.interceptors.response.use(
  function (response) {
    // 对响应数据做点什么
    if (response.data.code === -1) {
      localStorage.removeItem('token')
      localStorage.removeItem('refreshToken')

      ElMessage({
        type: MessageType.Warning,
        message: '登录已过期，请重新登陆',
        duration: 1500
      })
      router.push('/login')
    }
    return response.data
  },
  function (error) {
    // 对响应错误做点什么
    ElMessage({
      type: MessageType.Error,
      message: '服务器错误，请稍后再试',
      duration: 1500
    })
    // router.push('/login')
    return Promise.reject(error)
  }
)
// 导出实例
export default axiosInstance
