import { useTableStore } from '@/stores/useTable'
import { useRequest } from '@/hooks/useRequest'
import axiosInstance from '../axios/axiosInstance'
const { AllApi } = useRequest()

// 拿到所有游戏的信息
export const getAllGameInfo = async () => {
  try {
    const tableStore = useTableStore() // 这一句不要直接卸载函数外面，会导致在pinia挂载之前被调用

    if (tableStore.allGameInfo.length) return tableStore.allGameInfo
    else {
      const response = await axiosInstance.post(AllApi.getGameTable, {
        appSecret: '6YJSuc50uJ18zj45'
      })
      const result = JSON.parse(JSON.stringify(response))
      const data = result.data // 拿到返回的数据

      if (result.code === 0) {
        if (Array.isArray(data)) {
          let gameInfoList = data.map((item) => {
            return { gid: item.gid, gameName: item.gameName }
          })
          tableStore.setGameInfo(gameInfoList)
          return gameInfoList
        }
      } else {
        console.log('获取游戏列表失败')
        return []
      }
    }
  } catch (err) {
    console.log(err)
    throw new Error('获取游戏列表失败')
  }
}

/**
 * @description: 根据路由的name判断这个组件是否需要监听事件
 * @param {string} routeName 路由name,类型是来自RouteRecordNameGeneric类型
 * @return {*}
 */
export const shouldListenToEvent = (routeName: string | symbol | undefined, mathName: string) => {
  return routeName === mathName
}

/**
 * @description: 下载文件信息
 * @param {string} fileName 指定文件名
 * @param {any} info  需要下载的信息
 * @return {*}
 */
export const downLoadData = (fileName: string, info: any) => {
  let result = {
    ...info
  }
  let blob = new Blob([JSON.stringify(result)], { type: 'application/json' })
  let url = URL.createObjectURL(blob)
  let a = document.createElement('a')
  a.href = url
  a.download = fileName
  a.click()
  URL.revokeObjectURL(url)
}
